@@ -1,8 +1,11 @@
+"""module for schema loading for internal registered types"""
 import json
 import logging
 
 import importlib_resources as pkg_resources
 
+from datacraft import ResourceError
+
 from . import schema
 
 _log = logging.getLogger(__name__)
@@ -11,10 +14,9 @@ _log = logging.getLogger(__name__)
 def load_resource_as_json(resource_name: str) -> dict:
     """ loads the internal json resource with the given resource_name """
     try:
-        with pkg_resources.open_text(schema, resource_name) as schema_resource:
+        with (pkg_resources.files(schema) / resource_name).open('rb') as schema_resource:
             return json.load(schema_resource)
     except FileNotFoundError as err:
-        from datacraft import ResourceError
         raise ResourceError(f'No resource with name {resource_name} was found') from err
 
 
@@ -32,4 +34,11 @@ def load(key: str) -> dict:
         ResourceError if schema for key not found
     """
     naming_convention = f'{key}.schema.json'
-    return load_resource_as_json(naming_convention)
+
+    type_schema = load_resource_as_json(naming_convention)
+    definitions = load_resource_as_json('definitions.json')
+    if 'definitions' in type_schema:
+        type_schema['definitions'].update(definitions['definitions'])
+    else:
+        type_schema['definitions'] = definitions['definitions']
+    return type_schema
