@@ -1,4 +1,5 @@
-"""
+""" data spec formatting
+
 Module with functions that handle formatting specs in an orderly and consistent structure i.e:
 
 .. code-block:: json
@@ -28,6 +29,7 @@ from collections import OrderedDict
 
 import yaml
 from _ctypes import PyObj_FromPtr  # type: ignore
+from yaml import MarkedYAMLError
 
 _log = logging.getLogger('spec.formatter')
 
@@ -57,7 +59,7 @@ def format_yaml(raw_spec: dict) -> str:
         the ordered and formatted YAML string
     """
     ordered = _order_spec(raw_spec)
-    dirty_yaml = yaml.dump(ordered, sort_keys=False, width=4096).strip()
+    dirty_yaml = str(yaml.dump(ordered, sort_keys=False, width=4096)).strip()
     cleaned_yaml = _clean_semi_formatted_yaml(dirty_yaml)
     try:
         loaded_yaml = yaml.load(cleaned_yaml, Loader=yaml.FullLoader)
@@ -65,7 +67,7 @@ def format_yaml(raw_spec: dict) -> str:
             _log.warning('yaml does not match raw')
             _log.warning(json.dumps(loaded_yaml, indent=4))
             _log.warning(json.dumps(raw_spec, indent=4))
-    except Exception:
+    except MarkedYAMLError:
         _log.warning('yaml does not load')
         _log.warning(cleaned_yaml)
         _log.warning(dirty_yaml)
@@ -137,7 +139,7 @@ class _NoIndent:
         """
         Added to support formatting for YAML
         """
-        return representer.represent_scalar(' ', u'{.value}'.format(node))
+        return representer.represent_scalar(' ', f'{node.value}')
 
 
 class _MyEncoder(json.JSONEncoder):
