@@ -7,8 +7,8 @@ from .model import ValueSupplierInterface
 
 
 def combine_supplier(suppliers_list: List[ValueSupplierInterface],
-                     as_list: bool,
-                     join_with: str) -> ValueSupplierInterface:
+                     join_with: str,
+                     as_list: bool) -> ValueSupplierInterface:
     """
     Args:
         suppliers_list: list of suppliers to combine in order of combination
