@@ -12,7 +12,7 @@ _log = logging.getLogger(__name__)
 
 def date_supplier(date_format: str,
                   timestamp_distribution: Distribution,
-                  hour_supplier: ValueSupplierInterface = None) -> ValueSupplierInterface:
+                  hour_supplier: Union[ValueSupplierInterface, None] = None) -> ValueSupplierInterface:
     """
     Creates a value supplier that provides dates with the given format
 
@@ -27,6 +27,21 @@ def date_supplier(date_format: str,
     return _DateSupplier(timestamp_distribution, date_format, hour_supplier)
 
 
+def epoch_date_supplier(timestamp_distribution: Distribution,
+                        is_millis: bool = False) -> ValueSupplierInterface:
+    """
+    Creates a value supplier that provides dates with the given format
+
+    Args:
+        timestamp_distribution: distribution object that will provide the timestamps that will be formatted
+        is_millis: should this be a millisecond based timestamp
+
+    Returns:
+        ValueSupplierInterface that supplies dates with the given format
+    """
+    return _EpochDateSupplier(timestamp_distribution, is_millis)
+
+
 class _DateSupplier(ValueSupplierInterface):
     """
     Value Supplier implementation for dates
@@ -35,7 +50,7 @@ class _DateSupplier(ValueSupplierInterface):
     def __init__(self,
                  timestamp_distribution: Distribution,
                  date_format_string: str,
-                 hour_supplier: ValueSupplierInterface = None):
+                 hour_supplier: Union[ValueSupplierInterface, None] = None):
         """
         Args:
             timestamp_distribution: distribution for timestamps
@@ -57,6 +72,29 @@ class _DateSupplier(ValueSupplierInterface):
         return next_date.replace(microsecond=0).isoformat()
 
 
+class _EpochDateSupplier(ValueSupplierInterface):
+    """
+    Value Supplier implementation for epoch dates
+    """
+
+    def __init__(self,
+                 timestamp_distribution: Distribution,
+                 is_millis: bool = False):
+        """
+        Args:
+            timestamp_distribution: distribution for timestamps
+            is_millis: should this be a millisecond based timestamp
+        """
+        self.timestamp_distribution = timestamp_distribution
+        self.is_millis = is_millis
+
+    def next(self, iteration):
+        random_seconds = self.timestamp_distribution.next_value()
+        if self.is_millis:
+            return int(random_seconds*1000)
+        return int(random_seconds)
+
+
 def uniform_date_timestamp(
         start: str,
         end: str,
@@ -88,7 +126,7 @@ def uniform_date_timestamp(
         # buffer end date by one to keep inclusive
         try:
             end_date = datetime.datetime.strptime(end, date_format_string) \
-                       + datetime.timedelta(days=1) - offset_date
+                + datetime.timedelta(days=1) - offset_date
         except TypeError as err:
             raise ValueError(f"TypeError. Format: {date_format_string}, may not match param: {end}") from err
     else:
@@ -101,5 +139,3 @@ def uniform_date_timestamp(
         _log.warning("End date (%s) is before start date (%s)", start_date, end_date)
         return None, None
     return start_ts, end_ts
-
-
