@@ -3,7 +3,7 @@ Module to hold models for core data structures and classes
 """
 from abc import ABC, abstractmethod
 from collections.abc import Iterator
-from typing import Union, Tuple, List, Any, Generator
+from typing import Union, Tuple, List, Any, Generator, Dict
 
 
 class DataSpec(dict):
@@ -50,6 +50,7 @@ class DataSpec(dict):
     def pop(self, k, d=None):
         return self.raw_spec.pop(k, d)
 
+    @abstractmethod
     def generator(self, iterations: int, **kwargs) -> Generator:
         """
         Creates a generator that will produce records or render the template for each record
@@ -69,9 +70,8 @@ class DataSpec(dict):
 
         Examples:
             >>> import datacraft
-            >>> builder = datacraft.spec_builder()
-            >>> builder.values(['bob', 'bobby', 'robert', 'bobo']))
-            >>> spec = builder.build()
+            >>> raw_spec {'name': ['bob', 'bobby', 'robert', 'bobo']}
+            >>> spec = datacraft.parse_spec(raw_spec)
             >>> template = 'Name: {{ name }}'
             >>> processor = datacraft.outputs.processor(template=template)
             >>> generator = spec.generator(
