@@ -17,12 +17,13 @@ from .supplier.common import (SingleValue, MultipleValueSupplier, RotatingSuppli
 from .supplier.model import Distribution, ValueSupplierInterface, ResettableIterator
 from .supplier.combine import combine_supplier
 from .supplier.calculate import calculate_supplier
-from .supplier.date import date_supplier, uniform_date_timestamp
+from .supplier.date import date_supplier, uniform_date_timestamp, epoch_date_supplier
 from .supplier.csv import load_csv_data, csv_supplier
 from .supplier.uuid import uuid_supplier
 from .supplier.unicode import unicode_range_supplier
 from .supplier.templated import templated_supplier
 from .supplier import network, ranges
+from .supplier.strings import cut_supplier
 
 _log = logging.getLogger(__name__)
 
@@ -65,11 +66,15 @@ def values(spec: Any, **kwargs) -> ValueSupplierInterface:
 
     Examples:
         >>> import datacraft
-        >>> spec = {"type": "values", "data": [1,2,3,5,8,13]}
-        >>> fib_supplier = datacraft.suppliers.values(spec)
+        >>> raw_spec = {"type": "values", "data": [1,2,3,5,8,13]}
+        >>> fib_supplier = datacraft.suppliers.values(raw_spec)
         >>> fib_supplier = datacraft.suppliers.values([1,2,3,5,8,13])
+        >>> fib_supplier.next(0)
+        1
         >>> weights =  {"1": 0.1, "2": 0.2, "3": 0.1, "4": 0.2, "5": 0.1, "6": 0.2, "7": 0.1}
         >>> mostly_even_supplier = datacraft.suppliers.values(weights)
+        >>> mostly_even_supplier.next(0)
+        '4'
     """
     # shortcut notations no type, or data, the spec is the data
     if _data_not_in_spec(spec):
@@ -89,8 +94,8 @@ def values(spec: Any, **kwargs) -> ValueSupplierInterface:
         supplier = constant(data)
 
     # Check for count param
-        # if 'count' in kwargs or 'count_dist' in kwargs:
-        #     return MultipleValueSupplier(supplier, count_supplier(**kwargs))
+    # if 'count' in kwargs or 'count_dist' in kwargs:
+    #     return MultipleValueSupplier(supplier, count_supplier(**kwargs))
     return supplier
 
 
@@ -272,7 +277,7 @@ def list_values(data: list, **kwargs) -> ValueSupplierInterface:
     return list_value_supplier(data, count_supplier(**kwargs), sample, as_list)
 
 
-def weighted_values(data: dict, config: dict = None) -> ValueSupplierInterface:
+def weighted_values(data: dict, config: Union[dict, None] = None) -> ValueSupplierInterface:
     """
     Creates a weighted value supplier from the data, which is a mapping of value to the weight is should represent.
 
@@ -288,15 +293,29 @@ def weighted_values(data: dict, config: dict = None) -> ValueSupplierInterface:
 
     Examples:
         >>> import datacraft
-        >>> weights = {"dog": 0.5, "cat": 0.2, "bunny": 0.1, "hamster": 0.1, "pig": 0.05, "snake": 0.04, "_NULL_": 0.01}
-        >>> weighted_pet_supplier = datacraft.suppliers.weighted_values(weights)
+        >>> pets = {
+        ... "dog": 0.5, "cat": 0.2, "bunny": 0.1, "hamster": 0.1, "pig": 0.05, "snake": 0.04, "_NULL_": 0.01
+        ... }
+        >>> weighted_pet_supplier = datacraft.suppliers.weighted_values(pets)
         >>> most_likely_a_dog = weighted_pet_supplier.next(0)
     """
     if len(data) == 0:
         raise SpecException('Invalid Weights, no values defined')
     if config is None:
         config = {}
-    choices = [key if key not in ['_NONE_', '_NULL_'] else None for key in data.keys()]
+    replacements = {
+        '_NONE_': None,
+        '_NULL_': None,
+        '_NIL_': None,
+        '_TRUE_': True,
+        '_FALSE_': False
+    }
+    choices = []
+    for key in data.keys():
+        if key in replacements:
+            choices.append(replacements.get(key))
+        else:
+            choices.append(key)
     weights = list(data.values())
     if not isinstance(weights[0], float):
         raise SpecException('Invalid type for weights: ' + str(type(weights[0])))
@@ -305,7 +324,7 @@ def weighted_values(data: dict, config: dict = None) -> ValueSupplierInterface:
 
 def random_range(start: Union[str, int, float],
                  end: Union[str, int, float],
-                 precision: Union[str, int, float] = None,
+                 precision: Union[str, int, float, None] = None,
                  count: Union[int, List[int], Dict[str, float], Distribution] = 1) -> ValueSupplierInterface:
     """
     Creates a random range supplier for the start and end parameters with the given precision
@@ -321,9 +340,10 @@ def random_range(start: Union[str, int, float],
         the value supplier for the range
 
     Examples:
-        >>> range_supplier = datacraft.suppliers.random_range(5, 25, precision=3)
+        >>> num_supplier = datacraft.suppliers.random_range(5, 25, precision=3)
         >>> # should be between 5 and 25 with 3 decimal places
-        >>> next_value = range_supplier.next(0))
+        >>> num_supplier.next(0)
+        8.377
     """
     return RandomRangeSupplier(start, end, precision, count_supplier(data=count))
 
@@ -386,9 +406,11 @@ def list_count_sampler(data: list, **kwargs) -> ValueSupplierInterface:
         >>> import datacraft
         >>> pet_list = ["dog", "cat", "hamster", "pig", "rabbit", "horse"]
         >>> pet_supplier = datacraft.suppliers.list_count_sampler(pet_list, min=2, max=5)
-        >>> new_pets = pet_supplier.next(0)
-        >>> pet_supplier = datacraft.suppliers.list_count_sampler(pet_list, count_dist="normal(mean=2,min=1,max=3)")
-        >>> new_pets = pet_supplier.next(0)
+        >>> pet_supplier.next(0)
+        ['rabbit', 'cat', 'pig', 'cat']
+        >>> pet_supplier = datacraft.suppliers.list_count_sampler(pet_list, count_dist="normal(mean=2,stddev=1,min=1,max=3)")
+        >>> pet_supplier.next(0)
+        ['pig', 'horse']
     """
     if 'count' in kwargs or 'count_dist' in kwargs:
         counts = count_supplier(**kwargs)
@@ -434,14 +456,14 @@ def decorated(supplier: ValueSupplierInterface, **kwargs) -> ValueSupplierInterf
     Examples:
         >>> import datacraft
         >>> nums = datacraft.suppliers.values([1, 2, 3, 4, 5])
-        >>> supplier = datacraft.suppliers.decorated(nums, prefix='you are number ')
-        >>> supplier.next(0)
+        >>> prefix_supplier = datacraft.suppliers.decorated(nums, prefix='you are number ')
+        >>> prefix_supplier.next(0)
         you are number 1
-        >>> supplier = datacraft.suppliers.decorated(nums, suffix=' more minutes')
-        >>> supplier.next(0)
+        >>> suffix_supplier = datacraft.suppliers.decorated(nums, suffix=' more minutes')
+        >>> suffix_supplier.next(0)
         1 more minutes
-        >>> supplier = datacraft.suppliers.decorated(nums, quote='"')
-        >>> supplier.next(0)
+        >>> quoted_supplier = datacraft.suppliers.decorated(nums, quote='"')
+        >>> quoted_supplier.next(0)
         "1"
     """
     return DecoratedSupplier(supplier, **kwargs)
@@ -600,8 +622,7 @@ def date(**kwargs) -> ValueSupplierInterface:
         start (str): start date string
         end (str): end date string
         offset (int): number of days to shift the duration, positive is back negative is forward
-        duration_days (str): number of days after start, default is 30
-        date_format_string (str): format for parsing dates
+        duration_days (int): number of days after start, default is 30
 
     Returns:
         supplier for dates
@@ -612,17 +633,47 @@ def date(**kwargs) -> ValueSupplierInterface:
     return _create_uniform_date_supplier(hour_supplier, **kwargs)
 
 
+def epoch_date(as_millis: bool = False, **kwargs) -> ValueSupplierInterface:
+    """
+    Creates supplier the provides epoch dates
+
+    Can use one of center_date or (start, end, offset, duration_days) etc.
+
+    Args:
+        as_millis: if the timestamp should be millis since epoch, default is seconds
+
+    Keyword Args:
+        format (str): Format string for date args used, required if any provided
+        center_date (str): Date matching format to center dates around
+        stddev_days (float): Standard deviation in days from center date
+        start (str): start date string
+        end (str): end date string
+        offset (int): number of days to shift the duration, positive is back negative is forward
+        duration_days (str): number of days after start, default is 30
+
+    Returns:
+        supplier for dates
+    """
+    if 'center_date' in kwargs or 'stddev_days' in kwargs:
+        timestamp_distribution, _ = _gauss_date_timestamp(**kwargs)
+    else:
+        timestamp_distribution, _ = _uniform_date_timestamp(**kwargs)
+    return epoch_date_supplier(timestamp_distribution, is_millis=as_millis)
+
+
 def _create_stats_based_date_supplier(hour_supplier: ValueSupplierInterface, **kwargs):
     """ creates stats based date supplier from config """
-    center_date = kwargs.get('center_date')
-    stddev_days = kwargs.get('stddev_days', registries.get_default('date_stddev_days'))
-    date_format = kwargs.get('format', registries.get_default('date_format'))
-    timestamp_distribution = _gauss_date_timestamp(center_date, float(stddev_days), date_format)
+    timestamp_distribution, date_format = _gauss_date_timestamp(**kwargs)
     return date_supplier(date_format, timestamp_distribution, hour_supplier)
 
 
 def _create_uniform_date_supplier(hour_supplier: ValueSupplierInterface, **kwargs):
     """ creates uniform based date supplier from config """
+    timestamp_distribution, date_format = _uniform_date_timestamp(**kwargs)
+    return date_supplier(date_format, timestamp_distribution, hour_supplier)
+
+
+def _uniform_date_timestamp(**kwargs):
     duration_days = kwargs.get('duration_days', registries.get_default('date_duration_days'))
     offset = int(kwargs.get('offset', 0))
     start = kwargs.get('start')
@@ -632,34 +683,34 @@ def _create_uniform_date_supplier(hour_supplier: ValueSupplierInterface, **kwarg
     if start_ts is None or end_ts is None:
         raise SpecException(f'Unable to generate timestamp supplier from config: {json.dumps(kwargs)}')
     timestamp_distribution = distributions.uniform(start=start_ts, end=end_ts)
-    return date_supplier(date_format, timestamp_distribution, hour_supplier)
+    return timestamp_distribution, date_format
 
 
 _SECONDS_IN_DAY = 24.0 * 60.0 * 60.0
 
 
-def _gauss_date_timestamp(
-        center_date_str: Union[str, None],
-        stddev_days: float,
-        date_format_string: str):
+def _gauss_date_timestamp(**kwargs):
     """
     Creates a normally distributed date distribution around the center date
 
-    Args:
+    Keyword Args:
         center_date_str: center date for distribution
         stddev_days: standard deviation from center date in days
-        date_format_string: format for returned dates
+        format: format for returned dates
 
     Returns:
-        Distribution that gives normally distributed seconds since epoch for the given params
+        Distribution that gives normally distributed seconds since epoch for the given params, and date_format_string
     """
+    center_date_str = kwargs.get('center_date')
+    stddev_days = float(kwargs.get('stddev_days', registries.get_default('date_stddev_days')))
+    date_format_string = kwargs.get('format', registries.get_default('date_format'))
     if center_date_str:
         center_date = datetime.datetime.strptime(center_date_str, date_format_string)
     else:
         center_date = datetime.datetime.now()
     mean = center_date.timestamp()
     stddev = stddev_days * _SECONDS_IN_DAY
-    return distributions.normal(mean=mean, stddev=stddev)
+    return distributions.normal(mean=mean, stddev=stddev), date_format_string
 
 
 def geo_lat(**kwargs) -> ValueSupplierInterface:
@@ -869,7 +920,7 @@ def ip_precise(cidr: str, sample: bool = False) -> ValueSupplierInterface:
     return network.ip_precise(cidr, sample)
 
 
-def mac_address(delimiter: str = None) -> ValueSupplierInterface:
+def mac_address(delimiter: Union[str, None] = None) -> ValueSupplierInterface:
     """Creates a value supplier that produces mac addresses
 
     Args:
@@ -892,7 +943,7 @@ def mac_address(delimiter: str = None) -> ValueSupplierInterface:
     return network.mac_address(delimiter)
 
 
-def combine(to_combine, join_with: str = None, as_list: bool = None):
+def combine(to_combine, join_with: Union[str, None] = None, as_list: Union[bool, None] = None):
     """Creates a value supplier that will combine the outputs of the provided suppliers in order. The default is to
     join the values with an empty string. Provide the join_with config param to specify a different string to
     join the values with. Set as_list to true, if the values should be returned as a list and not joined
@@ -923,7 +974,7 @@ def combine(to_combine, join_with: str = None, as_list: bool = None):
     return combine_supplier(to_combine, join_with, as_list)
 
 
-def uuid(variant: int = None) -> ValueSupplierInterface:
+def uuid(variant: Union[int, None] = None) -> ValueSupplierInterface:
     """
     Creates a UUid Value Supplier
 
@@ -977,7 +1028,7 @@ def resettable(iterator: ResettableIterator):
     return iter_supplier(iterator)
 
 
-def select_list_subset(data: list, **kwargs):
+def sample(data: list, **kwargs):
     """Creates a supplier that selects elements from the data list based on the supplier kwargs
 
     Args:
@@ -986,9 +1037,20 @@ def select_list_subset(data: list, **kwargs):
     Keyword Args:
         mean (float): mean number of values to include in list
         stddev (float): standard deviation from the mean
+        count: number of elements in list to use
+        count_dist: count distribution to use
+        min: minimum number of values to return
+        max: maximum number of values to return
+        join_with: value to join values with, default is None
 
     Returns:
         supplier to supply subsets of data list
+
+    Examples:
+        >>> import datacraft
+        >>> supplier = datacraft.suppliers.sample(['dog', 'cat', 'rat'], mean=2)
+        >>> supplier.next(1)
+        ['cat', 'rat']
     """
     if utils.any_key_exists(kwargs, ['mean', 'stddev']):
         return list_stats_sampler(data, **kwargs)
@@ -1047,11 +1109,27 @@ def templated(supplier_map: Dict[str, ValueSupplierInterface],
 
     Examples:
         >>> from datacraft import suppliers
-        >>> supplier_map = { 'char': suppliers.values(['a', 'b', 'c']), 'num': suppliers.values([1, 2, 3]) }
-        >>> template_str = 'letter {{ char }}, number {{ num }}'
-        >>> supplier = suppliers.templated(supplier_map, template_str)
+        >>> char_to_num_supplier = { 'char': suppliers.values(['a', 'b', 'c']), 'num': suppliers.values([1, 2, 3]) }
+        >>> letter_number_template = 'letter {{ char }}, number {{ num }}'
+        >>> supplier = suppliers.templated(char_to_num_supplier, letter_number_template)
         >>> supplier.next(0)
         'letter a, nummber 1'
     """
     engine = template_engines.string(template_str)
     return templated_supplier(supplier_map, engine)
+
+
+def cut(supplier: datacraft.ValueSupplierInterface,
+        start: int = 0,
+        end: Union[int, None] = None):
+    """Trim output of given supplier from start to end, if length permits
+
+    Args:
+        supplier: to get output from
+        start: where in output string to cut from (inclusive)
+        end: where to end cut (exclusive)
+
+    Returns:
+        The shortened version of the output string
+    """
+    return cut_supplier(supplier, start, end)
